==> epiphany-2.26.3-x86_64-2gsb.txz: install/doinst.sh <==
( cd usr/share/gnome/help/epiphany/ru/figures ; rm -rf ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; ln -sf ../../C/figures/ephy-bookmarkbar-smartbookmark-screenshot.png ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; rm -rf ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; ln -sf ../../C/figures/ephy-screenshot.png ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; rm -rf ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; ln -sf ../../C/figures/ephy-history-window-screenshot.png ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; rm -rf ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; ln -sf ../../C/figures/ephy-addressbar-smartbookmark-screenshot.png ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; rm -rf ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; ln -sf ../../C/figures/ephy-bookmarkbar-smartbookmark-screenshot.png ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; rm -rf ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; ln -sf ../../C/figures/ephy-screenshot.png ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; rm -rf ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; ln -sf ../../C/figures/ephy-history-window-screenshot.png ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; rm -rf ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; ln -sf ../../C/figures/ephy-addressbar-smartbookmark-screenshot.png ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; rm -rf ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; ln -sf ../../C/figures/ephy-bookmarkbar-smartbookmark-screenshot.png ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; rm -rf ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; ln -sf ../../C/figures/ephy-screenshot.png ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; rm -rf ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; ln -sf ../../C/figures/ephy-history-window-screenshot.png ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; rm -rf ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; ln -sf ../../C/figures/ephy-addressbar-smartbookmark-screenshot.png ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; rm -rf ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; ln -sf ../../C/figures/ephy-bookmarkbar-smartbookmark-screenshot.png ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; rm -rf ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; ln -sf ../../C/figures/ephy-screenshot.png ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; rm -rf ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; ln -sf ../../C/figures/ephy-history-window-screenshot.png ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; rm -rf ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; ln -sf ../../C/figures/ephy-addressbar-smartbookmark-screenshot.png ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/el/figures ; rm -rf ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/el/figures ; ln -sf ../../C/figures/ephy-bookmarkbar-smartbookmark-screenshot.png ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/el/figures ; rm -rf ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/el/figures ; ln -sf ../../C/figures/ephy-history-window-screenshot.png ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/el/figures ; rm -rf ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/el/figures ; ln -sf ../../C/figures/ephy-addressbar-smartbookmark-screenshot.png ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/cs/figures ; rm -rf ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/cs/figures ; ln -sf ../../C/figures/ephy-bookmarkbar-smartbookmark-screenshot.png ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/cs/figures ; rm -rf ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/cs/figures ; ln -sf ../../C/figures/ephy-screenshot.png ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/cs/figures ; rm -rf ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/cs/figures ; ln -sf ../../C/figures/ephy-history-window-screenshot.png ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/cs/figures ; rm -rf ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/cs/figures ; ln -sf ../../C/figures/ephy-addressbar-smartbookmark-screenshot.png ephy-addressbar-smartbookmark-screenshot.png )

if [ -x usr/bin/gconftool-2 ]; then
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/epiphany-fonts.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/epiphany-lockdown.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/epiphany-pango.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/epiphany.schemas >/dev/null 2>&1
fi
# update rarian database
if [ -x usr/bin/rarian-sk-update ]; then
  usr/bin/rarian-sk-update 1> /dev/null 2> /dev/null
fi

# update desktop entries
if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi

# update hicolor icons
if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
        rm -f usr/share/icons/hicolor/icon-theme.cache
fi
usr/bin/gtk-update-icon-cache -f -q usr/share/icons/hicolor 1>/dev/null 2>/dev/null

# Restart gconfd-2 if running to reload new gconf settings
if ps acx | grep -q gconfd-2 ; then
        killall -HUP gconfd-2 ;
fi

==> epiphany-2.30.2-x86_64-1gsb.txz: install/doinst.sh <==
( cd usr/share/gnome/help/epiphany/en_GB/figures ; rm -rf ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; ln -sf ../../C/figures/ephy-bookmarkbar-smartbookmark-screenshot.png ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; rm -rf ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; ln -sf ../../C/figures/ephy-screenshot.png ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; rm -rf ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; ln -sf ../../C/figures/ephy-history-window-screenshot.png ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; rm -rf ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; ln -sf ../../C/figures/ephy-addressbar-smartbookmark-screenshot.png ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/eu/figures ; rm -rf ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/eu/figures ; ln -sf ../../C/figures/ephy-bookmarkbar-smartbookmark-screenshot.png ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/eu/figures ; rm -rf ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/eu/figures ; ln -sf ../../C/figures/ephy-addressbar-smartbookmark-screenshot.png ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/el/figures ; rm -rf ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/el/figures ; ln -sf ../../C/figures/ephy-bookmarkbar-smartbookmark-screenshot.png ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/el/figures ; rm -rf ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/el/figures ; ln -sf ../../C/figures/ephy-history-window-screenshot.png ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/el/figures ; rm -rf ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/el/figures ; ln -sf ../../C/figures/ephy-addressbar-smartbookmark-screenshot.png ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; rm -rf ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; ln -sf ../../C/figures/ephy-bookmarkbar-smartbookmark-screenshot.png ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; rm -rf ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; ln -sf ../../C/figures/ephy-screenshot.png ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; rm -rf ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; ln -sf ../../C/figures/ephy-history-window-screenshot.png ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; rm -rf ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; ln -sf ../../C/figures/ephy-addressbar-smartbookmark-screenshot.png ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; rm -rf ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; ln -sf ../../C/figures/ephy-bookmarkbar-smartbookmark-screenshot.png ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; rm -rf ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; ln -sf ../../C/figures/ephy-screenshot.png ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; rm -rf ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; ln -sf ../../C/figures/ephy-history-window-screenshot.png ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; rm -rf ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; ln -sf ../../C/figures/ephy-addressbar-smartbookmark-screenshot.png ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; rm -rf ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; ln -sf ../../C/figures/ephy-bookmarkbar-smartbookmark-screenshot.png ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; rm -rf ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; ln -sf ../../C/figures/ephy-screenshot.png ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; rm -rf ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; ln -sf ../../C/figures/ephy-history-window-screenshot.png ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; rm -rf ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; ln -sf ../../C/figures/ephy-addressbar-smartbookmark-screenshot.png ephy-addressbar-smartbookmark-screenshot.png )

if [ -x usr/bin/gconftool-2 ]; then
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"    usr/bin/gconftool-2 --makefile-install-rule    etc/gconf/schemas/epiphany-lockdown.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"    usr/bin/gconftool-2 --makefile-install-rule    etc/gconf/schemas/epiphany.schemas >/dev/null 2>&1
fi
# Update rarian database
if [ -x usr/bin/rarian-sk-update ]; then
  usr/bin/rarian-sk-update 1> /dev/null 2> /dev/null
fi

# update desktop entries
if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi

# update hicolor icons
if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
        rm -f usr/share/icons/hicolor/icon-theme.cache
fi
usr/bin/gtk-update-icon-cache -f -q usr/share/icons/hicolor 1>/dev/null 2>/dev/null

# Restart gconfd-2 if running to reload new gconf settings
if ps acx | grep -q gconfd-2 ; then
        killall -HUP gconfd-2 ;
fi
